"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.saveForm = exports.resetForm = exports.getForm = exports.deleteForm = exports.clearFormError = void 0;
var _lib = require("@arun-s-aot/formiojs/lib");
var types = _interopRequireWildcard(require("./constants"));
var _selectors = require("./selectors");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const clearFormError = name => ({
  type: types.FORM_CLEAR_ERROR,
  name
});
exports.clearFormError = clearFormError;
const requestForm = (name, id, url) => ({
  type: types.FORM_REQUEST,
  name,
  id,
  url
});
const receiveForm = (name, form, url) => ({
  type: types.FORM_SUCCESS,
  form,
  name,
  url
});
const failForm = (name, err) => ({
  type: types.FORM_FAILURE,
  error: err,
  name
});
const resetForm = name => ({
  type: types.FORM_RESET,
  name
});
exports.resetForm = resetForm;
const sendForm = (name, form) => ({
  type: types.FORM_SAVE,
  form,
  name
});
const getForm = function (name) {
  let id = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  let done = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};
  return (dispatch, getState) => {
    // Check to see if the form is already loaded.
    const form = (0, _selectors.selectForm)(name, getState());
    if (form.components && Array.isArray(form.components) && form.components.length && form._id === id) {
      return;
    }
    const path = `${_lib.Formio.getProjectUrl()}/${id ? `form/${id}` : name}`;
    const formio = new _lib.Formio(path);
    dispatch(requestForm(name, id, path));
    return formio.loadForm().then(result => {
      dispatch(receiveForm(name, result));
      done(null, result);
    }).catch(result => {
      dispatch(failForm(name, result));
      done(result);
    });
  };
};
exports.getForm = getForm;
const saveForm = function (name, form) {
  let done = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};
  return dispatch => {
    dispatch(sendForm(name, form));
    const id = form._id;
    const path = `${_lib.Formio.getProjectUrl()}/form${id ? `/${id}` : ''}`;
    const formio = new _lib.Formio(path);
    formio.saveForm(form).then(result => {
      const url = `${_lib.Formio.getProjectUrl()}/form/${result._id}`;
      dispatch(receiveForm(name, result, url));
      done(null, result);
    }).catch(result => {
      dispatch(failForm(name, result));
      done(result);
    });
  };
};
exports.saveForm = saveForm;
const deleteForm = function (name, id) {
  let done = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};
  return dispatch => {
    const path = `${_lib.Formio.getProjectUrl()}/form/${id}`;
    const formio = new _lib.Formio(path);
    return formio.deleteForm().then(() => {
      dispatch(resetForm(name));
      done();
    }).catch(result => {
      dispatch(failForm(name, result));
      done(result);
    });
  };
};
exports.deleteForm = deleteForm;