"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.saveSubmission = exports.resetSubmission = exports.getSubmission = exports.deleteSubmission = exports.clearSubmissionError = void 0;
var _lib = require("@arun-s-aot/formiojs/lib");
var types = _interopRequireWildcard(require("./constants"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const clearSubmissionError = name => ({
  type: types.SUBMISSION_CLEAR_ERROR,
  name
});
exports.clearSubmissionError = clearSubmissionError;
const requestSubmission = (name, id, formId, url) => ({
  type: types.SUBMISSION_REQUEST,
  name,
  id,
  formId,
  url
});
const sendSubmission = name => ({
  type: types.SUBMISSION_SAVE,
  name
});
const receiveSubmission = (name, submission, url) => ({
  type: types.SUBMISSION_SUCCESS,
  name,
  submission,
  url
});
const failSubmission = (name, error) => ({
  type: types.SUBMISSION_FAILURE,
  name,
  error
});
const resetSubmission = name => ({
  type: types.SUBMISSION_RESET,
  name
});
exports.resetSubmission = resetSubmission;
const getSubmission = function (name, id, formId) {
  let done = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : () => {};
  return (dispatch, getState) => {
    // Check to see if the submission is already loaded.
    if (getState().id === id) {
      return;
    }
    const url = `${_lib.Formio.getProjectUrl()}/${formId ? `form/${formId}` : name}/submission/${id}`;
    const formio = new _lib.Formio(url);
    dispatch(requestSubmission(name, id, formId, url));
    formio.loadSubmission().then(result => {
      dispatch(receiveSubmission(name, result));
      done(null, result);
    }).catch(error => {
      dispatch(failSubmission(name, error));
      done(error);
    });
  };
};
exports.getSubmission = getSubmission;
const saveSubmission = function (name, data, formId) {
  let done = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : () => {};
  return dispatch => {
    dispatch(sendSubmission(name, data));
    const id = data._id;
    const formio = new _lib.Formio(`${_lib.Formio.getProjectUrl()}/${formId ? `form/${formId}` : name}/submission${id ? `/${id}` : ''}`);
    formio.saveSubmission(data).then(result => {
      const url = `${_lib.Formio.getProjectUrl()}/${formId ? `form/${formId}` : name}/submission/${result._id}`;
      dispatch(receiveSubmission(name, result, url));
      done(null, result);
    }).catch(error => {
      dispatch(failSubmission(name, error));
      done(error);
    });
  };
};
exports.saveSubmission = saveSubmission;
const deleteSubmission = function (name, id, formId) {
  let done = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : () => {};
  return dispatch => {
    const formio = new _lib.Formio(`${_lib.Formio.getProjectUrl()}/${formId ? `form/${formId}` : name}/submission/${id}`);
    return formio.deleteSubmission().then(() => {
      dispatch(resetSubmission(name));
      done(null, true);
    }).catch(error => {
      dispatch(failSubmission(name, error));
      done(error);
    });
  };
};
exports.deleteSubmission = deleteSubmission;