"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PageSizes = exports.PageSize = exports.Operations = exports.Operation = exports.Columns = exports.Column = exports.AllItemsPerPage = void 0;
var _propTypes = _interopRequireDefault(require("prop-types"));
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
const AllItemsPerPage = exports.AllItemsPerPage = 'all';

/**
 * @typedef Column
 * @type {object}
 * @property {string} key
 * @property {(boolean|string|Function)} sort
 * @property {string} title
 * @property {Function} value
 * @property {number} width
 */

/**
 * @constant
 * @type {Column}
 */
const Column = exports.Column = _propTypes.default.shape({
  key: _propTypes.default.string.isRequired,
  sort: _propTypes.default.oneOfType([_propTypes.default.bool, _propTypes.default.string, _propTypes.default.func]),
  title: _propTypes.default.string,
  value: _propTypes.default.func,
  width: _propTypes.default.number
});

/**
 * @constant
 * @type {Column[]}
 */
const Columns = exports.Columns = _propTypes.default.arrayOf(Column);

/**
 * @typedef Operation
 * @type {object}
 * @property {string} [action]
 * @property {string} [buttonType]
 * @property {string} [icon]
 * @property {Function} [permissionsResolver]
 * @property {string} [title]
 */

/**
 * @constant
 * @type {Operation}
 */
const Operation = exports.Operation = _propTypes.default.shape({
  action: _propTypes.default.string.isRequired,
  buttonType: _propTypes.default.string,
  icon: _propTypes.default.string,
  permissionsResolver: _propTypes.default.func,
  title: _propTypes.default.string
});

/**
 * @constant
 * @type {Operation[]}
 */
const Operations = exports.Operations = _propTypes.default.arrayOf(Operation);

/**
 * @typedef LabelValue
 * @type {object}
 * @property {string} label
 * @property {number} value
 */

/**
 * @constant
 * @type {(number|LabelValue)}
 */
const PageSize = exports.PageSize = _propTypes.default.oneOfType([_propTypes.default.number, _propTypes.default.shape({
  label: _propTypes.default.string,
  value: _propTypes.default.number
}), _propTypes.default.oneOf([AllItemsPerPage])]);

/**
 * @constant
 * @type {PageSize[]}
 */
const PageSizes = exports.PageSizes = _propTypes.default.arrayOf(PageSize);